<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Api\Data;

use Magento\Framework\Api\CustomAttributesDataInterface;

/**
 * Interface ItemsInterface
 */
interface ItemsInterface extends CustomAttributesDataInterface
{
    const TABLE             = 'flat101_multiwidget_item';
    const ID                = 'entity_id';
    const STATUS            = 'status';
    const VISIBLE_FROM      = 'visible_from';
    const VISIBLE_TO        = 'visible_to';
    const IMAGE             = 'image';
    const TITLE             = 'title';
    const TITLE_HEADING     = 'title_heading';
    const SUBTITLE          = 'subtitle';
    const SUBTITLE_HEADING  = 'subtitle_heading';
    const BUTTON_TEXT       = 'button_text';
    const BUTTON_LINK       = 'button_link';
    const MULTI_WIDGET_ID   = 'multi_widget_id';
    const POSITION          = 'position';

    /**
     * Retrieve status
     *
     * @return int|null
     */
    public function getStatus(): int;

    /**
     * Set status
     *
     * @param int $status
     */
    public function setStatus(int $status);

    /**
     * Retrieve visible from date
     *
     * @return string|null
     */
    public function getVisibleFrom(): ?string;

    /**
     * Set visible from date
     *
     * @param string $visibleFrom
     */
    public function setVisibleFrom($visibleFrom);

    /**
     * Retrieve visible to date
     *
     * @return string|null
     */
    public function getVisibleTo(): ?string;

    /**
     * Set visible to date
     *
     * @param string $visibleTo
     */
    public function setVisibleTo($visibleTo);

    /**
     * Retrieve image
     *
     * @return string
     */
    public function getImage(): string;

    /**
     * Set image
     *
     * @param string $image
     */
    public function setImage(string $image);

    /**
     * Retrieve title
     *
     * @return string
     */
    public function getTitle(): string;

    /**
     * Set title
     *
     * @param string $title
     */
    public function setTitle(string $title);

    /**
     * Retrieve title heading
     *
     * @return string
     */
    public function getTitleHeading(): ?string;

    /**
     * Set title heading
     *
     * @param string $titleHeading
     */
    public function setTitleHeading(string $titleHeading);

    /**
     * Retrieve subtitle
     *
     * @return string
     */
    public function getSubtitle(): string;

    /**
     * Set subtitle
     *
     * @param string $subtitle
     */
    public function setSubtitle(string $subtitle);

    /**
     * Retrieve subtitle heading
     *
     * @return string
     */
    public function getSubtitleHeading(): ?string;

    /**
     * Set subtitle heading
     *
     * @param string $subtitleHeading
     */
    public function setSubtitleHeading(string $subtitleHeading);

    /**
     * Retrieve button text
     *
     * @return string
     */
    public function getButtonText(): ?string;

    /**
     * Set button text
     *
     * @param string $buttonText
     */
    public function setButtonText(string $buttonText);

    /**
     * Retrieve button link
     *
     * @return string
     */
    public function getButtonLink(): ?string;

    /**
     * Set button link
     *
     * @param string $buttonLink
     */
    public function setButtonLink(string $buttonLink);

    /**
     * Retrieve position
     *
     * @return int|null
     */
    public function getPosition(): ?int;

    /**
     * Set position
     *
     * @param int $position
     */
    public function setPosition(int $position);

    /**
     * Retrieve multi widget id
     *
     * @return int|null
     */
    public function getMultiWidgetId(): ?int;

    /**
     * Set multi widget id
     *
     * @param int $multiWidgetId
     */
    public function setMultiWidgetId(int $multiWidgetId);

    /**
     * Retrieve existing extension attributes object or create a new one.
     *
     * @return \Flat101\MultiWidget\Api\Data\ItemsExtensionInterface|null
     */
    public function getExtensionAttributes();

    /**
     * Set an extension attributes object.
     *
     * @param \Flat101\MultiWidget\Api\Data\ItemsExtensionInterface $extensionAttributes
     */
    public function setExtensionAttributes(\Flat101\MultiWidget\Api\Data\ItemsExtensionInterface $extensionAttributes);
}
