<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Api;

use Flat101\MultiWidget\Api\Data\ItemsInterface;
use Flat101\MultiWidget\Api\Data\ItemsSearchResultsInterface;
use Magento\Framework\Api\SearchCriteriaInterface;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\Exception\CouldNotDeleteException;

interface ItemsRepositoryInterface
{
    /**
     * Save Items
     *
     * @param ItemsInterface $items
     * @return ItemsInterface
     */
    public function save(ItemsInterface $items): ItemsInterface;

    /**
     * Retrieve MultiWidget by id
     *
     * @param int $entityId
     * @return ItemsInterface
     * @throws NoSuchEntityException
     */
    public function getById(int $entityId): ItemsInterface;

    /**
     * Retrieve MultiWidget by attribute
     *
     * @param $value
     * @param string|null $attributeCode
     * @return ItemsInterface
     * @throws NoSuchEntityException
     */
    public function get($value, ?string $attributeCode): ItemsInterface;

    /**
     * Delete $multiWidget.
     *
     * @param ItemsInterface $item
     * @return boolean
     * @throws CouldNotDeleteException
     */
    public function delete(ItemsInterface $item): bool;

    /**
     * Delete entity by ID.
     *
     * @param int $entityId
     * @return boolean
     * @throws NoSuchEntityException
     * @throws CouldNotDeleteException
     */
    public function deleteById(int $entityId): bool;

    /**
     * @param SearchCriteriaInterface $searchCriteria
     * @return ItemsSearchResultsInterface
     */
    public function getList(SearchCriteriaInterface $searchCriteria): ItemsSearchResultsInterface;
}
