<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Controller\Adminhtml\KeyBenefits;

use Flat101\MultiWidget\Controller\Adminhtml\MultiWidget;
use Flat101\MultiWidget\Api\MultiWidgetRepositoryInterface;
use Magento\Backend\App\Action\Context;
use Magento\Backend\Model\View\Result\Redirect;
use Magento\Backend\Model\View\Result\Page;
use Magento\Framework\View\Result\PageFactory;

class Edit extends MultiWidget
{
    const MENU_ID = 'Flat101_MultiWidget::key_benefits';

    /** @var MultiWidgetRepositoryInterface */
    private MultiWidgetRepositoryInterface $multiWidgetRepository;

    /** @var PageFactory */
    private PageFactory $resultPageFactory;

    public function __construct(
        MultiWidgetRepositoryInterface $multiWidgetRepository,
        PageFactory $resultPageFactory,
        Context $context
    ) {
        $this->multiWidgetRepository = $multiWidgetRepository;
        $this->resultPageFactory = $resultPageFactory;
        parent::__construct($context);
    }

    /**
     * @inheritDoc
     */
    public function execute()
    {
        $id = intval($this->getRequest()->getParam('entity_id'));
        $multiWidget = null;

        if ($id) {
            $multiWidget = $this->multiWidgetRepository->getById($id);
            if (!$multiWidget->getId()) {
                $this->messageManager->addErrorMessage(__('This key benefit no longer exists.'));
                /** @var Redirect $resultRedirect */
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }
        }

        /** @var Page $resultPage */
        $resultPage = $this->resultPageFactory->create();
        $this->initAction($resultPage);
        $resultPage->addBreadcrumb(
            $id ? __('Edit Key Benefit') : __('New Key Benefit'),
            $id ? __('Edit Key Benefit') : __('New Key Benefit')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('Key Benefit'));
        $resultPage->getConfig()->getTitle()
            ->prepend($multiWidget ? $multiWidget->getName() : __('New Key Benefit'));

        return $resultPage;
    }
}
