<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Controller\Adminhtml\Sliders;

use Flat101\MultiWidget\Helper\FileEraser;
use Flat101\MultiWidget\Api\MultiWidgetRepositoryInterface;
use Magento\Backend\App\Action\Context;
use Magento\Backend\App\Action;
use Exception;

class Delete extends Action
{
    const MENU_ID = 'Flat101_MultiWidget::sliders';

    /** @var MultiWidgetRepositoryInterface */
    private MultiWidgetRepositoryInterface $multiWidgetRepository;

    /** @var FileEraser */
    private FileEraser $fileEraser;

    public function __construct(
        MultiWidgetRepositoryInterface $multiWidgetRepository,
        FileEraser $fileEraser,
        Context $context
    ) {
        $this->multiWidgetRepository = $multiWidgetRepository;
        $this->fileEraser = $fileEraser;
        parent::__construct($context);
    }

    /**
     * @inheritDoc
     */
    public function execute()
    {
        $id = intval($this->getRequest()->getParam('id'));

        try {
            $multiWidget = $this->multiWidgetRepository->getById($id);
            if (!$multiWidget) {
                $this->messageManager->addErrorMessage(__('Unable to proceed. Please, try again.'));
            }

            $this->fileEraser->removeMultiWidgetImages($multiWidget, Upload::SLIDERS_IMAGE_PATH_DESTINATION);
            $this->multiWidgetRepository->delete($multiWidget);
            $this->messageManager->addSuccessMessage(__('Slider has been deleted successfully.'));
        } catch (Exception $e) {
            $this->messageManager->addErrorMessage(__('Error while trying to delete Slider: %1', $e->getMessage()));
        }

        $resultRedirect = $this->resultRedirectFactory->create();
        return $resultRedirect->setPath('*/*/index', array('_current' => true));
    }
}
