<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Helper;

use Flat101\MultiWidget\Api\Data\ItemsInterface;
use Flat101\MultiWidget\Api\Data\MultiWidgetInterface;
use Flat101\MultiWidget\Api\MultiWidgetRepositoryInterface;
use LogicException;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Filesystem;
use Magento\Framework\Filesystem\Io\File;

class FileEraser extends AbstractHelper
{
    /** @var MultiWidgetRepositoryInterface */
    private MultiWidgetRepositoryInterface $multiWidgetRepository;

    /** @var File */
    private File $fileIo;

    /** @var Filesystem */
    protected Filesystem $filesystem;

    public function __construct(
        MultiWidgetRepositoryInterface $multiWidgetRepository,
        File $fileIo,
        Filesystem $filesystem,
        Context $context
    ) {
        $this->multiWidgetRepository = $multiWidgetRepository;
        $this->fileIo = $fileIo;
        $this->filesystem = $filesystem;
        parent::__construct($context);
    }

    /**
     * @param MultiWidgetInterface $multiWidget
     * @param $destinationFolder
     */
    public function removeMultiWidgetImages(MultiWidgetInterface $multiWidget, $destinationFolder)
    {
        $items = $this->multiWidgetRepository->getItems($multiWidget);

        foreach ($items as $item) {
            $this->removeImage($item, $destinationFolder);
        }
    }

    /**
     * @param ItemsInterface $item
     * @param $destinationFolder
     */
    public function removeImage(ItemsInterface $item, $destinationFolder)
    {
        try {
            $imageName = $item->getImage();
            $fullPathDir = $this->filesystem->getDirectoryRead(DirectoryList::MEDIA)->getAbsolutePath() . $destinationFolder;

            $this->fileIo->rm($fullPathDir . $imageName);
        } catch (LogicException $exception) {
            throw new LogicException(__('Can not remove images from filesystem. Please try again or get in touch with us to solve the problem.'));
        }
    }
}
