<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Model;

use Flat101\MultiWidget\Api\Data\ItemsExtensionInterface;
use Flat101\MultiWidget\Api\Data\ItemsInterface;
use Flat101\MultiWidget\Model\ResourceModel\Items AS ResourceModelItems;
use Magento\Framework\Model\AbstractExtensibleModel;
use Magento\Framework\DataObject\IdentityInterface;

class Items extends AbstractExtensibleModel implements ItemsInterface, IdentityInterface
{
    const CACHE_TAG = 'flat101_multiwidget_items';

    /** @var string */
    protected $_cacheTag = self::CACHE_TAG;

    /** @var string */
    protected $_eventPrefix = self::CACHE_TAG;

    /**
     * Initialize model
     */
    protected function _construct()
    {
        $this->_init(ResourceModelItems::class);
    }

    /**
     * @inheritdoc
     */
    public function getStatus(): int
    {
        return intval($this->getData(ItemsInterface::STATUS));
    }

    /**
     * @inheritdoc
     */
    public function setStatus(int $status)
    {
        $this->setData(ItemsInterface::STATUS, $status);
    }

    /**
     * @inheritdoc
     */
    public function getVisibleFrom(): ?string
    {
        return $this->getData(ItemsInterface::VISIBLE_FROM);
    }

    /**
     * @inheritdoc
     */
    public function setVisibleFrom($visibleFrom)
    {
        $this->setData(ItemsInterface::VISIBLE_FROM, $visibleFrom);
    }

    /**
     * @inheritdoc
     */
    public function getVisibleTo(): ?string
    {
        return $this->getData(ItemsInterface::VISIBLE_TO);
    }

    /**
     * @inheritdoc
     */
    public function setVisibleTo($visibleTo)
    {
        $this->setData(ItemsInterface::VISIBLE_TO, $visibleTo);
    }

    /**
     * @inheritdoc
     */
    public function getImage(): string
    {
        return $this->getData(ItemsInterface::IMAGE);
    }

    /**
     * @inheritdoc
     */
    public function setImage(string $image)
    {
        $this->setData(ItemsInterface::IMAGE, $image);
    }

    /**
     * @inheritdoc
     */
    public function getTitle(): string
    {
        return $this->getData(ItemsInterface::TITLE);
    }

    /**
     * @inheritdoc
     */
    public function setTitle(string $title)
    {
        $this->setData(ItemsInterface::TITLE, $title);
    }

    /**
     * @inheritdoc
     */
    public function getTitleHeading(): ?string
    {
        return $this->getData(ItemsInterface::TITLE_HEADING);
    }

    /**
     * @inheritdoc
     */
    public function setTitleHeading(string $titleHeading)
    {
        $this->setData(ItemsInterface::TITLE_HEADING, $titleHeading);
    }

    /**
     * @inheritdoc
     */
    public function getSubtitle(): string
    {
        return $this->getData(ItemsInterface::SUBTITLE);
    }

    /**
     * @inheritdoc
     */
    public function setSubtitle(string $subtitle)
    {
        $this->setData(ItemsInterface::SUBTITLE, $subtitle);
    }

    /**
     * @inheritdoc
     */
    public function getSubtitleHeading(): ?string
    {
        return $this->getData(ItemsInterface::SUBTITLE_HEADING);
    }

    /**
     * @inheritdoc
     */
    public function setSubtitleHeading(string $subtitleHeading)
    {
        $this->setData(ItemsInterface::SUBTITLE_HEADING, $subtitleHeading);
    }

    /**
     * @inheritdoc
     */
    public function getButtonText(): ?string
    {
        return $this->getData(ItemsInterface::BUTTON_TEXT);
    }

    /**
     * @inheritdoc
     */
    public function setButtonText(string $buttonText)
    {
        $this->setData(ItemsInterface::BUTTON_TEXT, $buttonText);
    }

    /**
     * @inheritdoc
     */
    public function getButtonLink(): ?string
    {
        return $this->getData(ItemsInterface::BUTTON_LINK);
    }

    /**
     * @inheritdoc
     */
    public function setButtonLink(string $buttonLink)
    {
        $this->setData(ItemsInterface::BUTTON_LINK, $buttonLink);
    }

    /**
     * @inheritdoc
     */
    public function getPosition(): ?int
    {
        return intval($this->getData(ItemsInterface::POSITION));
    }

    /**
     * @inheritdoc
     */
    public function setPosition(int $position)
    {
        $this->setData(ItemsInterface::POSITION, $position);
    }

    /**
     * @inheritdoc
     */
    public function getMultiWidgetId(): ?int
    {
        return intval($this->getData(ItemsInterface::MULTI_WIDGET_ID));
    }

    /**
     * @inheritdoc
     */
    public function setMultiWidgetId(int $multiWidgetId)
    {
        $this->setData(ItemsInterface::MULTI_WIDGET_ID, $multiWidgetId);
    }

    /**
     * @inheritdoc
     */
    public function getExtensionAttributes()
    {
        return $this->_getExtensionAttributes();
    }

    /**
     * @inheritdoc
     */
    public function setExtensionAttributes(ItemsExtensionInterface $extensionAttributes): Items
    {
        return $this->_setExtensionAttributes($extensionAttributes);
    }

    /**
     * @inheritdoc
     */
    public function getIdentities(): array
    {
        return [self::CACHE_TAG . '_' . $this->getId()];
    }
}
