<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Model;

use Flat101\MultiWidget\Api\Data\MultiWidgetExtensionInterface;
use Flat101\MultiWidget\Api\Data\MultiWidgetInterface;
use Flat101\MultiWidget\Model\ResourceModel\MultiWidget AS ResourceModelMultiWidget;
use Magento\Framework\Model\AbstractExtensibleModel;
use Magento\Framework\DataObject\IdentityInterface;

class MultiWidget extends AbstractExtensibleModel implements MultiWidgetInterface, IdentityInterface
{
    const CACHE_TAG = 'flat101_multiwidget';

    /** @var string */
    protected $_cacheTag = self::CACHE_TAG;

    /** @var string */
    protected $_eventPrefix = self::CACHE_TAG;

    /**
     * Initialize model
     */
    protected function _construct()
    {
        $this->_init(ResourceModelMultiWidget::class);
    }

    /**
     * @inheritdoc
     */
    public function getName(): string
    {
        return $this->getData(MultiWidgetInterface::NAME);
    }

    /**
     * @inheritdoc
     */
    public function setName($name)
    {
        $this->setData(MultiWidgetInterface::NAME, $name);
    }

    /**
     * @inheritdoc
     */
    public function getNameHeading(): ?string
    {
        return $this->getData(MultiWidgetInterface::NAME_HEADING);
    }

    /**
     * @inheritdoc
     */
    public function setNameHeading(string $nameHeading)
    {
        $this->setData(MultiWidgetInterface::NAME_HEADING, $nameHeading);
    }

    /**
     * @inheritdoc
     */
    public function getDescription(): string
    {
         return $this->getData(MultiWidgetInterface::DESCRIPTION);
    }

    /**
     * @inheritdoc
     */
    public function setDescription(string $description)
    {
         $this->setData(MultiWidgetInterface::DESCRIPTION, $description);
    }

    /**
     * @inheritdoc
     */
    public function getDescriptionHeading(): ?string
    {
        return $this->getData(MultiWidgetInterface::DESCRIPTION_HEADING);
    }

    /**
     * @inheritdoc
     */
    public function setDescriptionHeading(string $descriptionHeading)
    {
        $this->setData(MultiWidgetInterface::DESCRIPTION_HEADING, $descriptionHeading);
    }

    /**
     * @inheritdoc
     */
    public function getStatus(): int
    {
        return intval($this->getData(MultiWidgetInterface::STATUS));
    }

    /**
     * @inheritdoc
     */
    public function setStatus(int $status)
    {
        $this->setData(MultiWidgetInterface::STATUS, $status);
    }

    /**
     * @inheritdoc
     */
    public function getVisibleFrom(): ?string
    {
        return $this->getData(MultiWidgetInterface::VISIBLE_FROM);
    }

    /**
     * @inheritdoc
     */
    public function setVisibleFrom($visibleFrom)
    {
        $this->setData(MultiWidgetInterface::VISIBLE_FROM, $visibleFrom);
    }

    /**
     * @inheritdoc
     */
    public function getVisibleTo(): ?string
    {
        return $this->getData(MultiWidgetInterface::VISIBLE_TO);
    }

    /**
     * @inheritdoc
     */
    public function setVisibleTo($visibleTo)
    {
        $this->setData(MultiWidgetInterface::VISIBLE_TO, $visibleTo);
    }

    /**
     * @inheritdoc
     */
    public function getTypeId(): ?int
    {
        return intval($this->getData(MultiWidgetInterface::TYPE_ID));
    }

    /**
     * @inheritdoc
     */
    public function setTypeId(int $typeId)
    {
        $this->setData(MultiWidgetInterface::TYPE_ID, $typeId);
    }

    /**
     * @inheritdoc
     */
    public function getExtensionAttributes()
    {
        return $this->_getExtensionAttributes();
    }

    /**
     * @inheritdoc
     */
    public function setExtensionAttributes(MultiWidgetExtensionInterface $extensionAttributes): MultiWidget
    {
        return $this->_setExtensionAttributes($extensionAttributes);
    }

    /**
     * @inheritdoc
     */
    public function getIdentities(): array
    {
        return [self::CACHE_TAG . '_' . $this->getId()];
    }
}
