<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Model\MultiWidget;

use Flat101\MultiWidget\Api\Data\MultiWidgetInterface;
use Flat101\MultiWidget\Model\ResourceModel\MultiWidget\CollectionFactory AS MultiWidgetCollectionFactory;
use Flat101\MultiWidget\Api\MultiWidgetRepositoryInterface;
use Magento\Ui\DataProvider\AbstractDataProvider;
use Magento\Store\Model\StoreManagerInterface;
use Magento\Framework\Exception\NoSuchEntityException;

abstract class DataProvider extends AbstractDataProvider
{
    /** @var array */
    protected $loadedData;

    /** @var StoreManagerInterface */
    protected StoreManagerInterface $storeManager;

    /** @var MultiWidgetRepositoryInterface */
    private MultiWidgetRepositoryInterface $multiWidgetRepository;

    /**
     * SlidersDataProvider constructor.
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param MultiWidgetCollectionFactory $multiWidgetCollectionFactory
     * @param StoreManagerInterface $storeManager
     * @param MultiWidgetRepositoryInterface $multiWidgetRepository
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        MultiWidgetCollectionFactory $multiWidgetCollectionFactory,
        StoreManagerInterface $storeManager,
        MultiWidgetRepositoryInterface $multiWidgetRepository,
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $multiWidgetCollectionFactory->create();
        $this->storeManager = $storeManager;
        $this->multiWidgetRepository = $multiWidgetRepository;
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
    }

    /**
     * Get data
     *
     * @return array|null
     * @throws NoSuchEntityException
     */
    public function getData(): ?array
    {
        if (isset($this->loadedData)) {
            return $this->loadedData;
        }

        $allMultiWidgets = $this->collection->getItems();
        foreach ($allMultiWidgets as $multiWidget) {
            /** @var MultiWidgetInterface $multiWidget */
            $this->loadedData[$multiWidget->getId()] = $multiWidget->getData();

            $itemCollection = $this->multiWidgetRepository->getItemsById(intval($multiWidget->getId()));

            foreach ($itemCollection->getItems() as $item) {
                $itemData = $item->getData();
                $itemData['image'] = $this->getImageData($itemData['image']);
                $this->loadedData[$multiWidget->getId()]['items'][] = $itemData;
            }
        }

        return $this->loadedData;
    }

    /**
     * @param string $imageName
     * @return array
     */
    abstract public function getImageData(string $imageName) :array;
}
