<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Model;

use Magento\Framework\Exception\CouldNotDeleteException;
use Magento\Framework\Exception\NoSuchEntityException;
use Flat101\MultiWidget\Api\Data\TypesInterface;
use Flat101\MultiWidget\Api\TypesRepositoryInterface;
use Flat101\MultiWidget\Model\ResourceModel\Types as ResourceModelTypes;
use Flat101\MultiWidget\Model\TypesFactory;

class TypesRepository implements TypesRepositoryInterface
{
    /** @var TypesFactory */
    private $typesFactory;

    /** @var ResourceModelTypes */
    private $resourceModelTypes;

    /**
     * TypesRepository constructor.
     *
     * @param TypesFactory $typesFactory
     * @param ResourceModelTypes $resourceModelTypes
     */
    public function __construct(
        TypesFactory $typesFactory,
        ResourceModelTypes $resourceModelTypes
    ) {
        $this->typesFactory             = $typesFactory;
        $this->resourceModelTypes       = $resourceModelTypes;
    }

    /**
     * @inheritdoc
     */
    public function save(TypesInterface $types): TypesInterface
    {
        $this->resourceModelTypes->save($types);

        return $types;
    }

    /**
     * @inheritdoc
     */
    public function getById(int $entityId): TypesInterface
    {
        return $this->get($entityId);
    }

    /**
     * @inheritdoc
     */
    public function get($value, $attributeCode = null): TypesInterface
    {
        /** @var Types $keyBenefits */
        $keyBenefits = $this->typesFactory->create()->load($value, $attributeCode);

        if (!$keyBenefits->getId()) {
            throw new NoSuchEntityException(__('Unable to find Types'));
        }

        return $keyBenefits;
    }
}
