<?php
declare(strict_types=1);

namespace Flat101\MultiWidget\Setup\Patch\Data;

use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchVersionInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Flat101\MultiWidget\Model\TypesRepository;
use Flat101\MultiWidget\Model\TypesFactory;

class AddData implements DataPatchInterface, PatchVersionInterface
{
    /** @var TypesRepository */
    private $typesRepository;

    /** @var TypesFactory */
    private $typesFactory;

    /** @var ModuleDataSetupInterface */
    private $moduleDataSetup;

    /**
     * @param TypesRepository $typesRepository
     * @param TypesFactory $typesFactory
     * @param ModuleDataSetupInterface $moduleDataSetup
     */
    public function __construct(
        TypesRepository $typesRepository,
        TypesFactory $typesFactory,
        ModuleDataSetupInterface $moduleDataSetup
    ) {
        $this->typesRepository = $typesRepository;
        $this->typesFactory = $typesFactory;
        $this->moduleDataSetup = $moduleDataSetup;
    }

    /**
     * {@inheritdoc}
     */
    public function apply()
    {
        $this->moduleDataSetup->startSetup();

        $typeSlider = $this->typesFactory->create();
        $typeSlider->setName('Slider');
        $this->typesRepository->save($typeSlider);

        $typeKB = $this->typesFactory->create();
        $typeKB->setName('Key Benefits');
        $this->typesRepository->save($typeKB);

        $this->moduleDataSetup->endSetup();
    }

    /**
     * {@inheritdoc}
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * {@inheritdoc}
     */
    public static function getVersion()
    {
        return '1.0.1';
    }

    /**
     * {@inheritdoc}
     */
    public function getAliases()
    {
        return [];
    }
}
